% compute 1-, 2- and 3-step-ahead forecasts for VARMA
% forecasts are computed assuming p <= 4, q=1

i = loop-burnin;
tempbeta = reshape(beta,p*n+1,n)';
mu = tempbeta(:,1);
A = tempbeta(:,2:end);
ftm1 = shortf(end-1,:)';
ftm0 = shortf(end,:)';            
Phi0 = B(:,1:n);
Phi1 = B(:,n+1:2*n);
            
Xt = reshape(shortYt(end:-1:end-p+1,:)', n*p,1);      
z1 = mu + A*Xt + Phi1*ftm0; % 1-step-ahead point forecasts
            
z1shortYt = [z1'; shortYt(end:-1:end-p+2,:)]';
Xt = reshape(z1shortYt( :, 1:p ),n*p,1);
z2 = mu + A*Xt; % 2-step-ahead point forecasts    
            
z1z2shortYt = [z2'; z1'; shortYt(end:-1:end-p+3,:)]';
Xt = reshape(z1z2shortYt( :, 1:p ),n*p,1);
z3 = mu + A*Xt; % 3-step-ahead point forecasts
          
dLam = diag(Lam); dOmega = diag(Omega);             
Sig1 = dLam+Phi0*dOmega*Phi0';  % covariance for 1-step-ahead forecasts
tempyhat1(i,:) = [log(normpdf(shortY(t+1,:),z1',sqrt(diag(Sig1))')) ...
    log(mvnpdf(shortY(t+1,:)',z1,Sig1))];           
if t<=T-2
    Sig2 = Phi0*dOmega*Phi0' + dLam;
    if p >= 1
        A1 = A(:,1:n);
        a1 = A1*Phi0+Phi1;
        Sig2 = Sig2 + a1*dOmega*a1' + A1*dLam*A1';  % covariance for 2-step-ahead forecasts                  
    end
    tempyhat2(i,:) = [log(normpdf(shortY(t+2,:),z2',sqrt(diag(Sig2))')) ...
        log(mvnpdf(shortY(t+2,:)',z2,Sig2))];               
end
if t<=T-3
    Sig3 = Phi0*dOmega*Phi0' + dLam;
    if p >= 1
        A1 = A(:,1:n);
        a1 = A1*Phi0+Phi1;
        Sig3 = Sig3 + a1*dOmega*a1' + A1*dLam*A1'; % covariance for 3-step-ahead forecasts                  
    end
    if p >= 2
        A2 = A(:,n+1:2*n);
        a2 = A1*a1+A2*Phi0;
        b1 = A1*A1+A2;           
        Sig3 = Sig3 + a2*dOmega*a2' + b1*dLam*b1';
    end
    tempyhat3(i,:) = [log(normpdf(shortY(t+3,:),z3',sqrt(diag(Sig3))')) ...
        log(mvnpdf(shortY(t+3,:)',z3,Sig3))];
end         
         